pygeodesy.css

Package pygeodesy :: Module css |
[frames] | no frames]

# Module css

Cassini-Soldner (CSS) projection.

Classes CassiniSoldner, Css and CSSError use Charles Karney's geographiclib Python package if installed, see property CassiniSoldner.geodesic.

Version: 25.04.14

Classes
| CSSError Cassini-Soldner (CSS) conversion or other Css issue.
| CassiniSoldner Cassini-Soldner projection, a Python version of Karney's C++ class CassiniSoldner.
| Css Cassini-Soldner East-/Northing location.
| EasNorAziRk4Tuple 4-Tuple `(easting, northing, azimuth, reciprocal)` for the Cassini-Soldner location with `easting` and `northing` in `meters` and the `azimuth` of easting direction and `reciprocal` of azimuthal northing scale, both in `degrees`.
| EasNorAziRkEqu6Tuple 6-Tuple `(easting, northing, azimuth, reciprocal, equatorarc, equatorazimuth)` for the Cassini-Soldner location with `easting` and `northing` in `meters` and the `azimuth` of easting direction, `reciprocal` of azimuthal northing scale, `equatorarc` and `equatorazimuth`, all in `degrees`.
| LatLonAziRk4Tuple 4-Tuple `(lat, lon, azimuth, reciprocal)`, all in `degrees` where `azimuth` is the azimuth of easting direction and `reciprocal` the reciprocal of azimuthal northing scale.

Functions
toCss(latlon, cs0=None, height=None, Css=<class 'pygeodesy.css.Css'>, **name) Convert an (ellipsoidal) geodetic point to a Cassini-Soldner location. |

Variables
| __all__ = `_ALL_LAZY.css`

Function Details

### toCss (latlon, cs0=None, height=None, Css=<class 'pygeodesy.css.Css'>, **name) |
Convert an (ellipsoidal) geodetic point to a Cassini-Soldner location. Arguments: `latlon` - Ellipsoidal point (`LatLon` or LatLon4Tuple). `cs0` - Optional, the Cassini-Soldner projection to use (CassiniSoldner). `height` - Optional height for the point, overriding the default height (`meter`). `Css` - Optional class to return the location (Css) or `None`. `name` - Optional `Css` `name=NN` (`str`). Returns: The Cassini-Soldner location (`Css`) or if `Css is None`, an EasNor3Tuple`(easting, northing, height)`. Raises: `CSSError` - Ellipsoidal mismatch of `latlon` and `cs0`. `ImportError` - Package geographiclib not installed or not found. `TypeError` - If `latlon` is not ellipsoidal.